@@ -27,6 +27,48 @@
 #include <list>
 #include <stddef.h> //for offsetof
 
+ /* Macros SSET_* and SGET_* are used to safely access fields in memory-mapped
+  * DOS structures represented via classes inheriting from MemStruct class.
+  *
+  * All of these macros depend on 'pt' base pointer from MemStruct base class;
+  * all DOS-specific fields are accessed by reading memory relative to that
+  * pointer.
+  *
+  * Example usage:
+  *
+  *   SSET_WORD(dos-structure-name, field-name, value);
+  *   uint16_t x = SGET_WORD(dos-structure-name, field-name);
+  */
+template <size_t N, typename S, typename T1, typename T2 = T1>
+constexpr PhysPt assert_macro_args_ok()
+{
+    static_assert(sizeof(T1) == N, "Requested struct field has unexpected size");
+    static_assert(sizeof(T2) == N, "Type used to save value has unexpected size");
+    static_assert(std::is_standard_layout<S>::value,
+        "Struct needs to have standard layout for offsetof calculation");
+    // returning 0, so compiler can optimize-out no-op "0 +" expression
+    return 0;
+}
+
+#define VERIFY_SSET_ARGS(n, s, f, v)                                           \
+	assert_macro_args_ok<n, s, decltype(s::f), decltype(v)>()
+#define VERIFY_SGET_ARGS(n, s, f)                                              \
+	assert_macro_args_ok<n, s, decltype(s::f)>()
+
+#define SSET_BYTE(s, f, v)                                                     \
+	mem_writeb(VERIFY_SSET_ARGS(1, s, f, v) + pt + offsetof(s, f), v)
+#define SSET_WORD(s, f, v)                                                     \
+	mem_writew(VERIFY_SSET_ARGS(2, s, f, v) + pt + offsetof(s, f), v)
+#define SSET_DWORD(s, f, v)                                                    \
+	mem_writed(VERIFY_SSET_ARGS(4, s, f, v) + pt + offsetof(s, f), v)
+
+#define SGET_BYTE(s, f)                                                        \
+	mem_readb(VERIFY_SGET_ARGS(1, s, f) + pt + offsetof(s, f))
+#define SGET_WORD(s, f)                                                        \
+	mem_readw(VERIFY_SGET_ARGS(2, s, f) + pt + offsetof(s, f))
+#define SGET_DWORD(s, f)                                                       \
+	mem_readd(VERIFY_SGET_ARGS(4, s, f) + pt + offsetof(s, f))
+
 #ifdef _MSC_VER
 #pragma pack (1)
 #endif
@@ -154,6 +196,10 @@ extern uint16_t DOS_MEM_START;// 0x158	 // regression to r3437 fixes nascar 2 co
 extern uint16_t DOS_PRIVATE_SEGMENT;// 0xc800
 extern uint16_t DOS_PRIVATE_SEGMENT_END;// 0xd000
 
+constexpr int SftHeaderSize = 6;
+constexpr int SftEntrySize = 59;
+constexpr int SftNumEntries = 16;
+
 /* internal Dos Tables */
 
 extern DOS_File ** Files;
@@ -277,6 +323,7 @@ bool DOS_ResizeMemory(uint16_t segment,uint16_t * blocks);
 bool DOS_FreeMemory(uint16_t segment);
 void DOS_FreeProcessMemory(uint16_t pspseg);
 uint16_t DOS_GetMemory(uint16_t pages,const char *who=NULL);
+void DOS_FreeTableMemory();
 bool DOS_SetMemAllocStrategy(uint16_t strat);
 uint16_t DOS_GetMemAllocStrategy(void);
 void DOS_BuildUMBChain(bool umb_active,bool ems_active);
