@@ -63,11 +63,11 @@ void PageHandler::writed(PhysPt addr,uint32_t val) {
 }
 
 HostPt PageHandler::GetHostReadPt(Bitu /*phys_page*/) {
-	return 0;
+	return nullptr;
 }
 
 HostPt PageHandler::GetHostWritePt(Bitu /*phys_page*/) {
-	return 0;
+	return nullptr;
 }
 
 bool PageHandler::readb_checked(PhysPt addr, uint8_t * val) {
@@ -377,7 +377,7 @@ private:
 		// replace this handler with the real thing
 		if (handler->getFlags() & PFLAG_WRITEABLE)
 			paging.tlb.write[lin_page] = handler->GetHostWritePt(phys_page) - (lin_page << 12);
-		else paging.tlb.write[lin_page]=0;
+		else paging.tlb.write[lin_page]=nullptr;
 		paging.tlb.writehandler[lin_page]=handler;
 
 		return;
@@ -388,41 +388,41 @@ private:
 	}
 public:
 	PageFoilHandler() : PageHandler(PFLAG_INIT|PFLAG_NOCODE) {}
-	uint8_t readb(PhysPt addr) {(void)addr;read();return 0;}
-	uint16_t readw(PhysPt addr) {(void)addr;read();return 0;}
-	uint32_t readd(PhysPt addr) {(void)addr;read();return 0;}
+	uint8_t readb(PhysPt addr) override {(void)addr;read();return 0;}
+	uint16_t readw(PhysPt addr) override {(void)addr;read();return 0;}
+	uint32_t readd(PhysPt addr) override {(void)addr;read();return 0;}
 
-    void writeb(PhysPt addr,uint8_t val) {
+    void writeb(PhysPt addr,uint8_t val) override {
         work(addr);
         // execute the write:
         // no need to care about mpl because we won't be entered
         // if write isn't allowed
         mem_writeb(addr,val);
     }
-    void writew(PhysPt addr,uint16_t val) {
+    void writew(PhysPt addr,uint16_t val) override {
         work(addr);
         mem_writew(addr,val);
     }
-    void writed(PhysPt addr,uint32_t val) {
+    void writed(PhysPt addr,uint32_t val) override {
         work(addr);
         mem_writed(addr,val);
     }
 
-    bool readb_checked(PhysPt addr, uint8_t * val) {(void)addr;(void)val;read();return true;}
-    bool readw_checked(PhysPt addr, uint16_t * val) {(void)addr;(void)val;read();return true;}
-    bool readd_checked(PhysPt addr, uint32_t * val) {(void)addr;(void)val;read();return true;}
+    bool readb_checked(PhysPt addr, uint8_t * val) override {(void)addr;(void)val;read();return true;}
+    bool readw_checked(PhysPt addr, uint16_t * val) override {(void)addr;(void)val;read();return true;}
+    bool readd_checked(PhysPt addr, uint32_t * val) override {(void)addr;(void)val;read();return true;}
 
-    bool writeb_checked(PhysPt addr,uint8_t val) {
+    bool writeb_checked(PhysPt addr,uint8_t val) override {
         work(addr);
         mem_writeb(addr,val);
         return false;
     }
-    bool writew_checked(PhysPt addr,uint16_t val) {
+    bool writew_checked(PhysPt addr,uint16_t val) override {
         work(addr);
         mem_writew(addr,val);
         return false;
     }
-    bool writed_checked(PhysPt addr,uint32_t val) {
+    bool writed_checked(PhysPt addr,uint32_t val) override {
         work(addr);
         mem_writed(addr,val);
         return false;
@@ -539,13 +539,13 @@ private:
 
 public:
 	ExceptionPageHandler() : PageHandler(PFLAG_INIT|PFLAG_NOCODE) {}
-	uint8_t readb(PhysPt addr) {
+	uint8_t readb(PhysPt addr) override {
 		if (!cpu.mpl) return readb_through(addr);
 			
 		Exception(addr, false, false);
 		return mem_readb(addr); // read the updated page (unlikely to happen?)
 				}
-	uint16_t readw(PhysPt addr) {
+	uint16_t readw(PhysPt addr) override {
 		// access type is supervisor mode (temporary)
 		// we are always allowed to read in superuser mode
 		// so get the handler and address and read it
@@ -554,13 +554,13 @@ public:
 		Exception(addr, false, false);
 		return mem_readw(addr);
 			}
-	uint32_t readd(PhysPt addr) {
+	uint32_t readd(PhysPt addr) override {
 		if (!cpu.mpl) return readd_through(addr);
 
 		Exception(addr, false, false);
 		return mem_readd(addr);
 		}
-	void writeb(PhysPt addr,uint8_t val) {
+	void writeb(PhysPt addr,uint8_t val) override {
 		if (!cpu.mpl) {
 			writeb_through(addr, val);
 			return;
@@ -568,7 +568,7 @@ public:
 		Exception(addr, true, false);
 		mem_writeb(addr, val);
 			}
-	void writew(PhysPt addr,uint16_t val) {
+	void writew(PhysPt addr,uint16_t val) override {
 		if (!cpu.mpl) {
 			// TODO Exception on a KR-page?
 			writew_through(addr, val);
@@ -584,7 +584,7 @@ public:
 		Exception(addr, true, false);
 		mem_writew(addr, val);
 	}
-	void writed(PhysPt addr,uint32_t val) {
+	void writed(PhysPt addr,uint32_t val) override {
 		if (!cpu.mpl) {
 			writed_through(addr, val);
 			return;
@@ -593,27 +593,27 @@ public:
 		mem_writed(addr, val);
 	}
 	// returning true means an exception was triggered for these _checked functions
-	bool readb_checked(PhysPt addr, uint8_t * val) {
+	bool readb_checked(PhysPt addr, uint8_t * val) override {
         (void)val;//UNUSED
 		Exception(addr, false, true);
 		return true;
 	}
-	bool readw_checked(PhysPt addr, uint16_t * val) {
+	bool readw_checked(PhysPt addr, uint16_t * val) override {
         (void)val;//UNUSED
 		Exception(addr, false, true);
 		return true;
 			}
-	bool readd_checked(PhysPt addr, uint32_t * val) {
+	bool readd_checked(PhysPt addr, uint32_t * val) override {
         (void)val;//UNUSED
 		Exception(addr, false, true);
 		return true;
 		}
-	bool writeb_checked(PhysPt addr,uint8_t val) {
+	bool writeb_checked(PhysPt addr,uint8_t val) override {
         (void)val;//UNUSED
 		Exception(addr, true, true);
 		return true;
 	}
-	bool writew_checked(PhysPt addr,uint16_t val) {
+	bool writew_checked(PhysPt addr,uint16_t val) override {
 		if (hack_check(addr)) {
 			LOG_MSG("Page attributes modified without clear");
 			PAGING_ClearTLB();
@@ -623,7 +623,7 @@ public:
 		Exception(addr, true, true);
 		return true;
 	}
-	bool writed_checked(PhysPt addr,uint32_t val) {
+	bool writed_checked(PhysPt addr,uint32_t val) override {
         (void)val;//UNUSED
 		Exception(addr, true, true);
 		return true;
@@ -698,57 +698,57 @@ static INLINE bool InitPage_CheckUseraccess(Bitu u1,Bitu u2) {
 class NewInitPageHandler : public PageHandler {
 public:
 	NewInitPageHandler() : PageHandler(PFLAG_INIT|PFLAG_NOCODE) {}
-	uint8_t readb(PhysPt addr) {
+	uint8_t readb(PhysPt addr) override {
 		InitPage(addr, false, false);
 		return mem_readb(addr);
 	}
-	uint16_t readw(PhysPt addr) {
+	uint16_t readw(PhysPt addr) override {
 		InitPage(addr, false, false);
 		return mem_readw(addr);
 	}
-	uint32_t readd(PhysPt addr) {
+	uint32_t readd(PhysPt addr) override {
 		InitPage(addr, false, false);
 		return mem_readd(addr);
 	}
-	void writeb(PhysPt addr,uint8_t val) {
+	void writeb(PhysPt addr,uint8_t val) override {
 		InitPage(addr, true, false);
 		mem_writeb(addr,val);
 	}
-	void writew(PhysPt addr,uint16_t val) {
+	void writew(PhysPt addr,uint16_t val) override {
 		InitPage(addr, true, false);
 		mem_writew(addr,val);
 	}
-	void writed(PhysPt addr,uint32_t val) {
+	void writed(PhysPt addr,uint32_t val) override {
 		InitPage(addr, true, false);
 		mem_writed(addr,val);
 	}
 
-	bool readb_checked(PhysPt addr, uint8_t * val) {
+	bool readb_checked(PhysPt addr, uint8_t * val) override {
 		if (InitPage(addr, false, true)) return true;
 		*val=mem_readb(addr);
 			return false;
 		}
-	bool readw_checked(PhysPt addr, uint16_t * val) {
+	bool readw_checked(PhysPt addr, uint16_t * val) override {
 		if (InitPage(addr, false, true)) return true;
 		*val=mem_readw(addr);
 		return false;
 	}
-	bool readd_checked(PhysPt addr, uint32_t * val) {
+	bool readd_checked(PhysPt addr, uint32_t * val) override {
 		if (InitPage(addr, false, true)) return true;
 		*val=mem_readd(addr);
 			return false;
 		}
-	bool writeb_checked(PhysPt addr,uint8_t val) {
+	bool writeb_checked(PhysPt addr,uint8_t val) override {
 		if (InitPage(addr, true, true)) return true;
 		mem_writeb(addr,val);
 		return false;
 	}
-	bool writew_checked(PhysPt addr,uint16_t val) {
+	bool writew_checked(PhysPt addr,uint16_t val) override {
 		if (InitPage(addr, true, true)) return true;
 		mem_writew(addr,val);
 			return false;
 		}
-	bool writed_checked(PhysPt addr,uint32_t val) {
+	bool writed_checked(PhysPt addr,uint32_t val) override {
 		if (InitPage(addr, true, true)) return true;
 		mem_writed(addr,val);
 		return false;
@@ -920,8 +920,8 @@ Bitu PAGING_GetDirBase(void) {
 #if defined(USE_FULL_TLB)
 void PAGING_InitTLB(void) {
 	for (Bitu i=0;i<TLB_SIZE;i++) {
-		paging.tlb.read[i]=0;
-		paging.tlb.write[i]=0;
+		paging.tlb.read[i]=nullptr;
+		paging.tlb.write[i]=nullptr;
 		paging.tlb.readhandler[i]=&init_page_handler;
 		paging.tlb.writehandler[i]=&init_page_handler;
 	}
@@ -938,8 +938,8 @@ void PAGING_ClearTLB(void) {
 	uint32_t * entries=&paging.links.entries[0];
 	for (;paging.links.used>0;paging.links.used--) {
 		Bitu page=*entries++;
-		paging.tlb.read[page]=0;
-		paging.tlb.write[page]=0;
+		paging.tlb.read[page]=nullptr;
+		paging.tlb.write[page]=nullptr;
 		paging.tlb.readhandler[page]=&init_page_handler;
 		paging.tlb.writehandler[page]=&init_page_handler;
 	}
@@ -951,8 +951,8 @@ void PAGING_ClearTLB(void) {
 
 void PAGING_UnlinkPages(Bitu lin_page,Bitu pages) {
 	for (;pages>0;pages--) {
-		paging.tlb.read[lin_page]=0;
-		paging.tlb.write[lin_page]=0;
+		paging.tlb.read[lin_page]=nullptr;
+		paging.tlb.write[lin_page]=nullptr;
 		paging.tlb.readhandler[lin_page]=&init_page_handler;
 		paging.tlb.writehandler[lin_page]=&init_page_handler;
 		lin_page++;
@@ -962,8 +962,8 @@ void PAGING_UnlinkPages(Bitu lin_page,Bitu pages) {
 void PAGING_MapPage(Bitu lin_page,Bitu phys_page) {
 	if (lin_page<LINK_START) {
 		paging.firstmb[lin_page]=(uint32_t)phys_page;
-		paging.tlb.read[lin_page]=0;
-		paging.tlb.write[lin_page]=0;
+		paging.tlb.read[lin_page]=nullptr;
+		paging.tlb.write[lin_page]=nullptr;
 		paging.tlb.readhandler[lin_page]=&init_page_handler;
 		paging.tlb.writehandler[lin_page]=&init_page_handler;
 	} else {
@@ -998,35 +998,35 @@ static void PAGING_LinkPageNew(Bitu lin_page, Bitu phys_page, Bitu linkmode, boo
 		// read
 		if (handler->getFlags() & PFLAG_READABLE) paging.tlb.read[lin_page] = 
 			handler->GetHostReadPt(phys_page)-lin_base;
-	else paging.tlb.read[lin_page]=0;
+	else paging.tlb.read[lin_page]=nullptr;
 	paging.tlb.readhandler[lin_page]=handler;
 		
 		// write
 		if (dirty) { // in case it is already dirty we don't need to check
 			if (handler->getFlags() & PFLAG_WRITEABLE) paging.tlb.write[lin_page] = 
 				handler->GetHostWritePt(phys_page)-lin_base;
-			else paging.tlb.write[lin_page]=0;
+			else paging.tlb.write[lin_page]=nullptr;
 	paging.tlb.writehandler[lin_page]=handler;
 		} else {
 			paging.tlb.writehandler[lin_page]= &foiling_handler;
-			paging.tlb.write[lin_page]=0;
+			paging.tlb.write[lin_page]=nullptr;
 		}
 		break;
 	case ACMAP_RE:
 		// read
 		if (handler->getFlags() & PFLAG_READABLE) paging.tlb.read[lin_page] = 
 			handler->GetHostReadPt(phys_page)-lin_base;
-		else paging.tlb.read[lin_page]=0;
+		else paging.tlb.read[lin_page]=nullptr;
 		paging.tlb.readhandler[lin_page]=handler;
 		// exception
 		paging.tlb.writehandler[lin_page]= &exception_handler;
-		paging.tlb.write[lin_page]=0;
+		paging.tlb.write[lin_page]=nullptr;
 		break;
 	case ACMAP_EE:
 		paging.tlb.readhandler[lin_page]= &exception_handler;
 		paging.tlb.writehandler[lin_page]= &exception_handler;
-		paging.tlb.read[lin_page]=0;
-		paging.tlb.write[lin_page]=0;
+		paging.tlb.read[lin_page]=nullptr;
+		paging.tlb.write[lin_page]=nullptr;
 		break;
 }
 
@@ -1060,9 +1060,9 @@ void PAGING_LinkPage(Bitu lin_page,Bitu phys_page) {
 
 	paging.tlb.phys_page[lin_page]= (uint32_t)phys_page;
 	if (handler->getFlags() & PFLAG_READABLE) paging.tlb.read[lin_page]=handler->GetHostReadPt(phys_page)-lin_base;
-	else paging.tlb.read[lin_page]=0;
+	else paging.tlb.read[lin_page]=nullptr;
 	if (handler->getFlags() & PFLAG_WRITEABLE) paging.tlb.write[lin_page]=handler->GetHostWritePt(phys_page)-lin_base;
-	else paging.tlb.write[lin_page]=0;
+	else paging.tlb.write[lin_page]=nullptr;
 
 	paging.links.entries[paging.links.used++]= (uint32_t)lin_page;
 	paging.tlb.readhandler[lin_page]=handler;
@@ -1084,8 +1084,8 @@ void PAGING_SwitchCPL(bool isUser) {
 			Bitu tlb_index = paging.krw_links.entries[i];
 			paging.tlb.readhandler[tlb_index] = &exception_handler;
 			paging.tlb.writehandler[tlb_index] = &exception_handler;
-			paging.tlb.read[tlb_index] = 0;
-			paging.tlb.write[tlb_index] = 0;
+			paging.tlb.read[tlb_index] = nullptr;
+			paging.tlb.write[tlb_index] = nullptr;
 		}
 	} else {
 		// us -> sv: ee -> rw
@@ -1101,17 +1101,17 @@ void PAGING_SwitchCPL(bool isUser) {
 			paging.tlb.readhandler[tlb_index] = handler;
 			if (handler->getFlags()&PFLAG_READABLE)
 				paging.tlb.read[tlb_index] = handler->GetHostReadPt(phys_page)-lin_base;
-			else paging.tlb.read[tlb_index] = 0;
+			else paging.tlb.read[tlb_index] = nullptr;
 			
 			// map write handler
 			if (dirty) {
 				paging.tlb.writehandler[tlb_index] = handler;
 				if (handler->getFlags()&PFLAG_WRITEABLE)
 					paging.tlb.write[tlb_index] = handler->GetHostWritePt(phys_page)-lin_base;
-				else paging.tlb.write[tlb_index] = 0;
+				else paging.tlb.write[tlb_index] = nullptr;
 			} else {
 				paging.tlb.writehandler[tlb_index] = &foiling_handler;
-				paging.tlb.write[tlb_index] = 0;
+				paging.tlb.write[tlb_index] = nullptr;
 			}
 		}
 	}
@@ -1124,7 +1124,7 @@ void PAGING_SwitchCPL(bool isUser) {
 			for(Bitu i = 0; i < paging.kr_links.used; i++) {
 				Bitu tlb_index = paging.kr_links.entries[i];
 				paging.tlb.readhandler[tlb_index] = &exception_handler;
-				paging.tlb.read[tlb_index] = 0;
+				paging.tlb.read[tlb_index] = nullptr;
 			}
 		} else {
 			// us -> sv: ee -> re
@@ -1137,7 +1137,7 @@ void PAGING_SwitchCPL(bool isUser) {
 				paging.tlb.readhandler[tlb_index] = handler;
 				if (handler->getFlags()&PFLAG_READABLE)
 					paging.tlb.read[tlb_index] = handler->GetHostReadPt(phys_page)-lin_base;
-				else paging.tlb.read[tlb_index] = 0;
+				else paging.tlb.read[tlb_index] = nullptr;
 			}
 		}
 	} else { // WP=0
@@ -1147,7 +1147,7 @@ void PAGING_SwitchCPL(bool isUser) {
 			for(Bitu i = 0; i < paging.ur_links.used; i++) {
 				Bitu tlb_index = paging.ur_links.entries[i];
 				paging.tlb.writehandler[tlb_index] = &exception_handler;
-				paging.tlb.write[tlb_index] = 0;
+				paging.tlb.write[tlb_index] = nullptr;
 			}
 		} else {
 			// us -> sv: re -> rw
@@ -1163,10 +1163,10 @@ void PAGING_SwitchCPL(bool isUser) {
 					paging.tlb.writehandler[tlb_index] = handler;
 					if (handler->getFlags()&PFLAG_WRITEABLE)
 						paging.tlb.write[tlb_index] = handler->GetHostWritePt(phys_page)-lin_base;
-					else paging.tlb.write[tlb_index] = 0;
+					else paging.tlb.write[tlb_index] = nullptr;
 				} else {
 					paging.tlb.writehandler[tlb_index] = &foiling_handler;
-					paging.tlb.write[tlb_index] = 0;
+					paging.tlb.write[tlb_index] = nullptr;
 				}
 			}
 		}
@@ -1284,19 +1284,19 @@ public:
 	InitPageUserROHandler() {
 		flags=PFLAG_INIT|PFLAG_NOCODE;
 	}
-	void writeb(PhysPt addr,uint8_t val) {
+	void writeb(PhysPt addr,uint8_t val) override {
 		InitPage(addr,true,false);
 		host_writeb(get_tlb_read(addr)+addr,(uint8_t)(val&0xff));
 	}
-	void writew(PhysPt addr,uint16_t val) {
+	void writew(PhysPt addr,uint16_t val) override {
 		InitPage(addr,true,false);
 		host_writew(get_tlb_read(addr)+addr,(uint16_t)(val&0xffff));
 	}
-	void writed(PhysPt addr,uint32_t val) {
+	void writed(PhysPt addr,uint32_t val) override {
 		InitPage(addr,true,false);
 		host_writed(get_tlb_read(addr)+addr,(uint32_t)val);
 	}
-	bool writeb_checked(PhysPt addr,uint8_t val) {
+	bool writeb_checked(PhysPt addr,uint8_t val) override {
 		Bitu writecode=InitPageCheckOnly(addr,(uint8_t)(val&0xff));
 		if (writecode) {
 			HostPt tlb_addr;
@@ -1307,7 +1307,7 @@ public:
 		}
 		return true;
 	}
-	bool writew_checked(PhysPt addr,uint16_t val) {
+	bool writew_checked(PhysPt addr,uint16_t val) override {
 		Bitu writecode=InitPageCheckOnly(addr,(uint16_t)(val&0xffff));
 		if (writecode) {
 			HostPt tlb_addr;
@@ -1318,7 +1318,7 @@ public:
 		}
 		return true;
 	}
-	bool writed_checked(PhysPt addr,uint32_t val) {
+	bool writed_checked(PhysPt addr,uint32_t val) override {
 		Bitu writecode=InitPageCheckOnly(addr,(uint32_t)val);
 		if (writecode) {
 			HostPt tlb_addr;
@@ -1531,8 +1531,8 @@ void POD_Load_CPU_Paging( std::istream& stream )
 	PAGING_ClearTLB();
 
 	for( int lcv=0; lcv<TLB_SIZE; lcv++ ) {
-		paging.tlb.read[lcv] = 0;
-		paging.tlb.write[lcv] = 0;
+		paging.tlb.read[lcv] = nullptr;
+		paging.tlb.write[lcv] = nullptr;
 		paging.tlb.readhandler[lcv] = &init_page_handler;
 		paging.tlb.writehandler[lcv] = &init_page_handler;
 	}
