@@ -179,9 +179,9 @@ static INLINE void ScalerAddLines( Bitu changed, Bitu count ) {
 #if RENDER_USE_ADVANCED_SCALERS>1
 ScalerLineBlock_t ScalerCache = {
 {	Cache_8_8,	Cache_8_15 ,	Cache_8_16 ,	Cache_8_32 },
-{	        0,	Cache_15_15,	Cache_15_16,	Cache_15_32},
-{	        0,	Cache_16_15,	Cache_16_16,	Cache_16_32},
-{	        0,	Cache_32_15,	Cache_32_16,	Cache_32_32},
+{	nullptr,	Cache_15_15,	Cache_15_16,	Cache_15_32},
+{	nullptr,	Cache_16_15,	Cache_16_16,	Cache_16_32},
+{	nullptr,	Cache_32_15,	Cache_32_16,	Cache_32_32},
 {	Cache_8_8,	Cache_9_15 ,	Cache_9_16 ,	Cache_9_32 }
 };
 #endif
@@ -191,15 +191,15 @@ ScalerSimpleBlock_t ScaleNormal1x = {
 	GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
 	1,1,{
 {	Normal1x_8_8_L,		Normal1x_8_15_L ,	Normal1x_8_16_L ,	Normal1x_8_32_L },
-{	             0,		Normal1x_15_15_L,	Normal1x_15_16_L,	Normal1x_15_32_L},
-{	             0,		Normal1x_16_15_L,	Normal1x_16_16_L,	Normal1x_16_32_L},
-{	             0,		Normal1x_32_15_L,	Normal1x_32_16_L,	Normal1x_32_32_L},
+{	nullptr,		Normal1x_15_15_L,	Normal1x_15_16_L,	Normal1x_15_32_L},
+{	nullptr,		Normal1x_16_15_L,	Normal1x_16_16_L,	Normal1x_16_32_L},
+{	nullptr,		Normal1x_32_15_L,	Normal1x_32_16_L,	Normal1x_32_32_L},
 {	Normal1x_8_8_L,		Normal1x_9_15_L ,	Normal1x_9_16_L ,	Normal1x_9_32_L }
 },{
 {	Normal1x_8_8_R,		Normal1x_8_15_R ,	Normal1x_8_16_R ,	Normal1x_8_32_R },
-{	             0,		Normal1x_15_15_R,	Normal1x_15_16_R,	Normal1x_15_32_R},
-{	             0,		Normal1x_16_15_R,	Normal1x_16_16_R,	Normal1x_16_32_R},
-{	             0,		Normal1x_32_15_R,	Normal1x_32_16_R,	Normal1x_32_32_R},
+{	nullptr,		Normal1x_15_15_R,	Normal1x_15_16_R,	Normal1x_15_32_R},
+{	nullptr,		Normal1x_16_15_R,	Normal1x_16_16_R,	Normal1x_16_32_R},
+{	nullptr,		Normal1x_32_15_R,	Normal1x_32_16_R,	Normal1x_32_32_R},
 {	Normal1x_8_8_R,		Normal1x_9_15_R ,	Normal1x_9_16_R ,	Normal1x_9_32_R }
 }};
 
@@ -208,15 +208,15 @@ ScalerSimpleBlock_t ScaleNormalDw = {
 	GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
 	2,1,{
 {	NormalDw_8_8_L,		NormalDw_8_15_L ,	NormalDw_8_16_L ,	NormalDw_8_32_L },
-{	             0,		NormalDw_15_15_L,	NormalDw_15_16_L,	NormalDw_15_32_L},
-{	             0,		NormalDw_16_15_L,	NormalDw_16_16_L,	NormalDw_16_32_L},
-{	             0,		NormalDw_32_15_L,	NormalDw_32_16_L,	NormalDw_32_32_L},
+{	nullptr,		NormalDw_15_15_L,	NormalDw_15_16_L,	NormalDw_15_32_L},
+{	nullptr,		NormalDw_16_15_L,	NormalDw_16_16_L,	NormalDw_16_32_L},
+{	nullptr,		NormalDw_32_15_L,	NormalDw_32_16_L,	NormalDw_32_32_L},
 {	NormalDw_8_8_L,		NormalDw_9_15_L ,	NormalDw_9_16_L ,	NormalDw_9_32_L }
 },{
 {	NormalDw_8_8_R,		NormalDw_8_15_R ,	NormalDw_8_16_R ,	NormalDw_8_32_R },
-{	             0,		NormalDw_15_15_R,	NormalDw_15_16_R,	NormalDw_15_32_R},
-{	             0,		NormalDw_16_15_R,	NormalDw_16_16_R,	NormalDw_16_32_R},
-{	             0,		NormalDw_32_15_R,	NormalDw_32_16_R,	NormalDw_32_32_R},
+{	nullptr,		NormalDw_15_15_R,	NormalDw_15_16_R,	NormalDw_15_32_R},
+{	nullptr,		NormalDw_16_15_R,	NormalDw_16_16_R,	NormalDw_16_32_R},
+{	nullptr,		NormalDw_32_15_R,	NormalDw_32_16_R,	NormalDw_32_32_R},
 {	NormalDw_8_8_R,		NormalDw_9_15_R ,	NormalDw_9_16_R ,	NormalDw_9_32_R }
 }};
 
@@ -225,15 +225,15 @@ ScalerSimpleBlock_t ScaleNormalDh = {
 	GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
 	1,2,{
 {	NormalDh_8_8_L,		NormalDh_8_15_L ,	NormalDh_8_16_L ,	NormalDh_8_32_L },
-{	             0,		NormalDh_15_15_L,	NormalDh_15_16_L,	NormalDh_15_32_L},
-{	             0,		NormalDh_16_15_L,	NormalDh_16_16_L,	NormalDh_16_32_L},
-{	             0,		NormalDh_32_15_L,	NormalDh_32_16_L,	NormalDh_32_32_L},
+{	nullptr,		NormalDh_15_15_L,	NormalDh_15_16_L,	NormalDh_15_32_L},
+{	nullptr,		NormalDh_16_15_L,	NormalDh_16_16_L,	NormalDh_16_32_L},
+{	nullptr,		NormalDh_32_15_L,	NormalDh_32_16_L,	NormalDh_32_32_L},
 {	NormalDh_8_8_L,		NormalDh_9_15_L ,	NormalDh_9_16_L ,	NormalDh_9_32_L }
 },{
 {	NormalDh_8_8_R,		NormalDh_8_15_R ,	NormalDh_8_16_R ,	NormalDh_8_32_R },
-{	             0,		NormalDh_15_15_R,	NormalDh_15_16_R,	NormalDh_15_32_R},
-{	             0,		NormalDh_16_15_R,	NormalDh_16_16_R,	NormalDh_16_32_R},
-{	             0,		NormalDh_32_15_R,	NormalDh_32_16_R,	NormalDh_32_32_R},
+{	nullptr,		NormalDh_15_15_R,	NormalDh_15_16_R,	NormalDh_15_32_R},
+{	nullptr,		NormalDh_16_15_R,	NormalDh_16_16_R,	NormalDh_16_32_R},
+{	nullptr,		NormalDh_32_15_R,	NormalDh_32_16_R,	NormalDh_32_32_R},
 {	NormalDh_8_8_R,		NormalDh_9_15_R ,	NormalDh_9_16_R ,	NormalDh_9_32_R }
 }};
 
@@ -242,15 +242,15 @@ ScalerSimpleBlock_t ScaleNormal2xDw = {
 	GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
 	4,2,{
 {	Normal2xDw_8_8_L,		Normal2xDw_8_15_L ,	Normal2xDw_8_16_L ,	Normal2xDw_8_32_L },
-{	               0,		Normal2xDw_15_15_L,	Normal2xDw_15_16_L,	Normal2xDw_15_32_L},
-{	               0,		Normal2xDw_16_15_L,	Normal2xDw_16_16_L,	Normal2xDw_16_32_L},
-{	               0,		Normal2xDw_32_15_L,	Normal2xDw_32_16_L,	Normal2xDw_32_32_L},
+{	nullptr,		Normal2xDw_15_15_L,	Normal2xDw_15_16_L,	Normal2xDw_15_32_L},
+{	nullptr,		Normal2xDw_16_15_L,	Normal2xDw_16_16_L,	Normal2xDw_16_32_L},
+{	nullptr,		Normal2xDw_32_15_L,	Normal2xDw_32_16_L,	Normal2xDw_32_32_L},
 {	Normal2xDw_8_8_L,		Normal2xDw_9_15_L ,	Normal2xDw_9_16_L ,	Normal2xDw_9_32_L }
 },{
 {	Normal2xDw_8_8_R,		Normal2xDw_8_15_R ,	Normal2xDw_8_16_R ,	Normal2xDw_8_32_R },
-{	               0,		Normal2xDw_15_15_R,	Normal2xDw_15_16_R,	Normal2xDw_15_32_R},
-{	               0,		Normal2xDw_16_15_R,	Normal2xDw_16_16_R,	Normal2xDw_16_32_R},
-{	               0,		Normal2xDw_32_15_R,	Normal2xDw_32_16_R,	Normal2xDw_32_32_R},
+{	nullptr,		Normal2xDw_15_15_R,	Normal2xDw_15_16_R,	Normal2xDw_15_32_R},
+{	nullptr,		Normal2xDw_16_15_R,	Normal2xDw_16_16_R,	Normal2xDw_16_32_R},
+{	nullptr,		Normal2xDw_32_15_R,	Normal2xDw_32_16_R,	Normal2xDw_32_32_R},
 {	Normal2xDw_8_8_R,		Normal2xDw_9_15_R ,	Normal2xDw_9_16_R ,	Normal2xDw_9_32_R }
 }};
 
@@ -259,15 +259,15 @@ ScalerSimpleBlock_t ScaleNormal2xDh = {
 	GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
 	2,4,{
 {	Normal2xDh_8_8_L,		Normal2xDh_8_15_L ,	Normal2xDh_8_16_L ,	Normal2xDh_8_32_L },
-{	               0,		Normal2xDh_15_15_L,	Normal2xDh_15_16_L,	Normal2xDh_15_32_L},
-{	               0,		Normal2xDh_16_15_L,	Normal2xDh_16_16_L,	Normal2xDh_16_32_L},
-{	               0,		Normal2xDh_32_15_L,	Normal2xDh_32_16_L,	Normal2xDh_32_32_L},
+{	nullptr,		Normal2xDh_15_15_L,	Normal2xDh_15_16_L,	Normal2xDh_15_32_L},
+{	nullptr,		Normal2xDh_16_15_L,	Normal2xDh_16_16_L,	Normal2xDh_16_32_L},
+{	nullptr,		Normal2xDh_32_15_L,	Normal2xDh_32_16_L,	Normal2xDh_32_32_L},
 {	Normal2xDh_8_8_L,		Normal2xDh_9_15_L ,	Normal2xDh_9_16_L ,	Normal2xDh_9_32_L }
 },{
 {	Normal2xDh_8_8_R,		Normal2xDh_8_15_R ,	Normal2xDh_8_16_R ,	Normal2xDh_8_32_R },
-{	               0,		Normal2xDh_15_15_R,	Normal2xDh_15_16_R,	Normal2xDh_15_32_R},
-{	               0,		Normal2xDh_16_15_R,	Normal2xDh_16_16_R,	Normal2xDh_16_32_R},
-{	               0,		Normal2xDh_32_15_R,	Normal2xDh_32_16_R,	Normal2xDh_32_32_R},
+{	nullptr,		Normal2xDh_15_15_R,	Normal2xDh_15_16_R,	Normal2xDh_15_32_R},
+{	nullptr,		Normal2xDh_16_15_R,	Normal2xDh_16_16_R,	Normal2xDh_16_32_R},
+{	nullptr,		Normal2xDh_32_15_R,	Normal2xDh_32_16_R,	Normal2xDh_32_32_R},
 {	Normal2xDh_8_8_R,		Normal2xDh_9_15_R ,	Normal2xDh_9_16_R ,	Normal2xDh_9_32_R }
 }};
 
@@ -276,15 +276,15 @@ ScalerSimpleBlock_t ScaleNormal2x = {
 	GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
 	2,2,{
 {	Normal2x_8_8_L,		Normal2x_8_15_L,	Normal2x_8_16_L,	Normal2x_8_32_L },
-{	             0,		Normal2x_15_15_L,	Normal2x_15_16_L,	Normal2x_15_32_L},
-{	             0,		Normal2x_16_15_L,	Normal2x_16_16_L,	Normal2x_16_32_L},
-{	             0,		Normal2x_32_15_L,	Normal2x_32_16_L,	Normal2x_32_32_L},
+{	nullptr,		Normal2x_15_15_L,	Normal2x_15_16_L,	Normal2x_15_32_L},
+{	nullptr,		Normal2x_16_15_L,	Normal2x_16_16_L,	Normal2x_16_32_L},
+{	nullptr,		Normal2x_32_15_L,	Normal2x_32_16_L,	Normal2x_32_32_L},
 {	Normal2x_8_8_L,		Normal2x_9_15_L ,	Normal2x_9_16_L,	Normal2x_9_32_L }
 },{
 {	Normal2x_8_8_R,		Normal2x_8_15_R ,	Normal2x_8_16_R,	Normal2x_8_32_R },
-{	             0,		Normal2x_15_15_R,	Normal2x_15_16_R,	Normal2x_15_32_R},
-{	             0,		Normal2x_16_15_R,	Normal2x_16_16_R,	Normal2x_16_32_R},
-{	             0,		Normal2x_32_15_R,	Normal2x_32_16_R,	Normal2x_32_32_R},
+{	nullptr,		Normal2x_15_15_R,	Normal2x_15_16_R,	Normal2x_15_32_R},
+{	nullptr,		Normal2x_16_15_R,	Normal2x_16_16_R,	Normal2x_16_32_R},
+{	nullptr,		Normal2x_32_15_R,	Normal2x_32_16_R,	Normal2x_32_32_R},
 {	Normal2x_8_8_R,		Normal2x_9_15_R ,	Normal2x_9_16_R,	Normal2x_9_32_R },
 }};
 
@@ -293,15 +293,15 @@ ScalerSimpleBlock_t ScaleNormal3x = {
 	GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
 	3,3,{
 {	Normal3x_8_8_L,		Normal3x_8_15_L ,	Normal3x_8_16_L ,	Normal3x_8_32_L },
-{	             0,		Normal3x_15_15_L,	Normal3x_15_16_L,	Normal3x_15_32_L},
-{	             0,		Normal3x_16_15_L,	Normal3x_16_16_L,	Normal3x_16_32_L},
-{	             0,		Normal3x_32_15_L,	Normal3x_32_16_L,	Normal3x_32_32_L},
+{	nullptr,		Normal3x_15_15_L,	Normal3x_15_16_L,	Normal3x_15_32_L},
+{	nullptr,		Normal3x_16_15_L,	Normal3x_16_16_L,	Normal3x_16_32_L},
+{	nullptr,		Normal3x_32_15_L,	Normal3x_32_16_L,	Normal3x_32_32_L},
 {	Normal3x_8_8_L,		Normal3x_9_15_L ,	Normal3x_9_16_L ,	Normal3x_9_32_L }
 },{
 {	Normal3x_8_8_R,		Normal3x_8_15_R ,	Normal3x_8_16_R ,	Normal3x_8_32_R },
-{	             0,		Normal3x_15_15_R,	Normal3x_15_16_R,	Normal3x_15_32_R},
-{	             0,		Normal3x_16_15_R,	Normal3x_16_16_R,	Normal3x_16_32_R},
-{	             0,		Normal3x_32_15_R,	Normal3x_32_16_R,	Normal3x_32_32_R},
+{	nullptr,		Normal3x_15_15_R,	Normal3x_15_16_R,	Normal3x_15_32_R},
+{	nullptr,		Normal3x_16_15_R,	Normal3x_16_16_R,	Normal3x_16_32_R},
+{	nullptr,		Normal3x_32_15_R,	Normal3x_32_16_R,	Normal3x_32_32_R},
 {	Normal3x_8_8_R,		Normal3x_9_15_R ,	Normal3x_9_16_R ,	Normal3x_9_32_R }
 }};
 
@@ -310,15 +310,15 @@ ScalerSimpleBlock_t ScaleNormal4x = {
     GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
     4,4,{
 {    Normal4x_8_8_L,        Normal4x_8_15_L ,    Normal4x_8_16_L ,    Normal4x_8_32_L },
-{                 0,        Normal4x_15_15_L,    Normal4x_15_16_L,    Normal4x_15_32_L},
-{                 0,        Normal4x_16_15_L,    Normal4x_16_16_L,    Normal4x_16_32_L},
-{                 0,        Normal4x_32_15_L,    Normal4x_32_16_L,    Normal4x_32_32_L},
+{    nullptr,               Normal4x_15_15_L,    Normal4x_15_16_L,    Normal4x_15_32_L},
+{    nullptr,               Normal4x_16_15_L,    Normal4x_16_16_L,    Normal4x_16_32_L},
+{    nullptr,               Normal4x_32_15_L,    Normal4x_32_16_L,    Normal4x_32_32_L},
 {    Normal4x_8_8_L,        Normal4x_9_15_L ,    Normal4x_9_16_L ,    Normal4x_9_32_L }
 },{
 {    Normal4x_8_8_R,        Normal4x_8_15_R ,    Normal4x_8_16_R ,    Normal4x_8_32_R },
-{                 0,        Normal4x_15_15_R,    Normal4x_15_16_R,    Normal4x_15_32_R},
-{                 0,        Normal4x_16_15_R,    Normal4x_16_16_R,    Normal4x_16_32_R},
-{                 0,        Normal4x_32_15_R,    Normal4x_32_16_R,    Normal4x_32_32_R},
+{    nullptr,               Normal4x_15_15_R,    Normal4x_15_16_R,    Normal4x_15_32_R},
+{    nullptr,               Normal4x_16_15_R,    Normal4x_16_16_R,    Normal4x_16_32_R},
+{    nullptr,               Normal4x_32_15_R,    Normal4x_32_16_R,    Normal4x_32_32_R},
 {    Normal4x_8_8_R,        Normal4x_9_15_R ,    Normal4x_9_16_R ,    Normal4x_9_32_R }
 }};
 
@@ -327,15 +327,15 @@ ScalerSimpleBlock_t ScaleNormal5x = {
     GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
     5,5,{
 {    Normal5x_8_8_L,        Normal5x_8_15_L ,    Normal5x_8_16_L ,    Normal5x_8_32_L },
-{                 0,        Normal5x_15_15_L,    Normal5x_15_16_L,    Normal5x_15_32_L},
-{                 0,        Normal5x_16_15_L,    Normal5x_16_16_L,    Normal5x_16_32_L},
-{                 0,        Normal5x_32_15_L,    Normal5x_32_16_L,    Normal5x_32_32_L},
+{    nullptr,               Normal5x_15_15_L,    Normal5x_15_16_L,    Normal5x_15_32_L},
+{    nullptr,               Normal5x_16_15_L,    Normal5x_16_16_L,    Normal5x_16_32_L},
+{    nullptr,               Normal5x_32_15_L,    Normal5x_32_16_L,    Normal5x_32_32_L},
 {    Normal5x_8_8_L,        Normal5x_9_15_L ,    Normal5x_9_16_L ,    Normal5x_9_32_L }
 },{
 {    Normal5x_8_8_R,        Normal5x_8_15_R ,    Normal5x_8_16_R ,    Normal5x_8_32_R },
-{                 0,        Normal5x_15_15_R,    Normal5x_15_16_R,    Normal5x_15_32_R},
-{                 0,        Normal5x_16_15_R,    Normal5x_16_16_R,    Normal5x_16_32_R},
-{                 0,        Normal5x_32_15_R,    Normal5x_32_16_R,    Normal5x_32_32_R},
+{    nullptr,               Normal5x_15_15_R,    Normal5x_15_16_R,    Normal5x_15_32_R},
+{    nullptr,               Normal5x_16_15_R,    Normal5x_16_16_R,    Normal5x_16_32_R},
+{    nullptr,               Normal5x_32_15_R,    Normal5x_32_16_R,    Normal5x_32_32_R},
 {    Normal5x_8_8_R,        Normal5x_9_15_R ,    Normal5x_9_16_R ,    Normal5x_9_32_R }
 }};
 
@@ -344,15 +344,15 @@ ScalerSimpleBlock_t ScaleNormal5x = {
     GFX_CAN_8|GFX_CAN_15|GFX_CAN_16|GFX_CAN_32,
     6,6,{
 {    Normal6x_8_8_L,        Normal6x_8_15_L ,    Normal6x_8_16_L ,    Normal6x_8_32_L },
-{                 0,        Normal6x_15_15_L,    Normal6x_15_16_L,    Normal6x_15_32_L},
-{                 0,        Normal6x_16_15_L,    Normal6x_16_16_L,    Normal6x_16_32_L},
-{                 0,        Normal6x_32_15_L,    Normal6x_32_16_L,    Normal6x_32_32_L},
+{    nullptr,               Normal6x_15_15_L,    Normal6x_15_16_L,    Normal6x_15_32_L},
+{    nullptr,               Normal6x_16_15_L,    Normal6x_16_16_L,    Normal6x_16_32_L},
+{    nullptr,               Normal6x_32_15_L,    Normal6x_32_16_L,    Normal6x_32_32_L},
 {    Normal6x_8_8_L,        Normal6x_9_15_L ,    Normal6x_9_16_L ,    Normal6x_9_32_L }
 },{
 {    Normal6x_8_8_R,        Normal6x_8_15_R ,    Normal6x_8_16_R ,    Normal6x_8_32_R },
-{                 0,        Normal6x_15_15_R,    Normal6x_15_16_R,    Normal6x_15_32_R},
-{                 0,        Normal6x_16_15_R,    Normal6x_16_16_R,    Normal6x_16_32_R},
-{                 0,        Normal6x_32_15_R,    Normal6x_32_16_R,    Normal6x_32_32_R},
+{    nullptr,               Normal6x_15_15_R,    Normal6x_15_16_R,    Normal6x_15_32_R},
+{    nullptr,               Normal6x_16_15_R,    Normal6x_16_16_R,    Normal6x_16_32_R},
+{    nullptr,               Normal6x_32_15_R,    Normal6x_32_16_R,    Normal6x_32_32_R},
 {    Normal6x_8_8_R,        Normal6x_9_15_R ,    Normal6x_9_16_R ,    Normal6x_9_32_R }
 }};*/
 
@@ -361,204 +361,204 @@ ScalerSimpleBlock_t ScaleTV2x = {
 	"TV2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,2,{
-{	0,		TV2x_8_15_L ,	TV2x_8_16_L ,	TV2x_8_32_L },
-{	0,		TV2x_15_15_L,	TV2x_15_16_L,	TV2x_15_32_L},
-{	0,		TV2x_16_15_L,	TV2x_16_16_L,	TV2x_16_32_L},
-{	0,		TV2x_32_15_L,	TV2x_32_16_L,	TV2x_32_32_L},
-{	0,		TV2x_9_15_L ,	TV2x_9_16_L ,	TV2x_9_32_L }
+{	nullptr,	TV2x_8_15_L ,	TV2x_8_16_L ,	TV2x_8_32_L },
+{	nullptr,	TV2x_15_15_L,	TV2x_15_16_L,	TV2x_15_32_L},
+{	nullptr,	TV2x_16_15_L,	TV2x_16_16_L,	TV2x_16_32_L},
+{	nullptr,	TV2x_32_15_L,	TV2x_32_16_L,	TV2x_32_32_L},
+{	nullptr,	TV2x_9_15_L ,	TV2x_9_16_L ,	TV2x_9_32_L }
 },{
-{	0,		TV2x_8_15_R ,	TV2x_8_16_R ,	TV2x_8_32_R },
-{	0,		TV2x_15_15_R,	TV2x_15_16_R,	TV2x_15_32_R},
-{	0,		TV2x_16_15_R,	TV2x_16_16_R,	TV2x_16_32_R},
-{	0,		TV2x_32_15_R,	TV2x_32_16_R,	TV2x_32_32_R},
-{	0,		TV2x_9_15_R ,	TV2x_9_16_R ,	TV2x_9_32_R }
+{	nullptr,	TV2x_8_15_R ,	TV2x_8_16_R ,	TV2x_8_32_R },
+{	nullptr,	TV2x_15_15_R,	TV2x_15_16_R,	TV2x_15_32_R},
+{	nullptr,	TV2x_16_15_R,	TV2x_16_16_R,	TV2x_16_32_R},
+{	nullptr,	TV2x_32_15_R,	TV2x_32_16_R,	TV2x_32_32_R},
+{	nullptr,	TV2x_9_15_R ,	TV2x_9_16_R ,	TV2x_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleTVDh = {
 	"TV2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	1,2,{
-{	0,		TVDh_8_15_L ,	TVDh_8_16_L ,	TVDh_8_32_L },
-{	0,		TVDh_15_15_L,	TVDh_15_16_L,	TVDh_15_32_L},
-{	0,		TVDh_16_15_L,	TVDh_16_16_L,	TVDh_16_32_L},
-{	0,		TVDh_32_15_L,	TVDh_32_16_L,	TVDh_32_32_L},
-{	0,		TVDh_9_15_L ,	TVDh_9_16_L ,	TVDh_9_32_L }
+{	nullptr,	TVDh_8_15_L ,	TVDh_8_16_L ,	TVDh_8_32_L },
+{	nullptr,	TVDh_15_15_L,	TVDh_15_16_L,	TVDh_15_32_L},
+{	nullptr,	TVDh_16_15_L,	TVDh_16_16_L,	TVDh_16_32_L},
+{	nullptr,	TVDh_32_15_L,	TVDh_32_16_L,	TVDh_32_32_L},
+{	nullptr,	TVDh_9_15_L ,	TVDh_9_16_L ,	TVDh_9_32_L }
 },{
-{	0,		TVDh_8_15_R ,	TVDh_8_16_R ,	TVDh_8_32_R },
-{	0,		TVDh_15_15_R,	TVDh_15_16_R,	TVDh_15_32_R},
-{	0,		TVDh_16_15_R,	TVDh_16_16_R,	TVDh_16_32_R},
-{	0,		TVDh_32_15_R,	TVDh_32_16_R,	TVDh_32_32_R},
-{	0,		TVDh_9_15_R ,	TVDh_9_16_R ,	TVDh_9_32_R }
+{	nullptr,	TVDh_8_15_R ,	TVDh_8_16_R ,	TVDh_8_32_R },
+{	nullptr,	TVDh_15_15_R,	TVDh_15_16_R,	TVDh_15_32_R},
+{	nullptr,	TVDh_16_15_R,	TVDh_16_16_R,	TVDh_16_32_R},
+{	nullptr,	TVDh_32_15_R,	TVDh_32_16_R,	TVDh_32_32_R},
+{	nullptr,	TVDh_9_15_R ,	TVDh_9_16_R ,	TVDh_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleTV3x = {
 	"TV3x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	3,3,{
-{	0,		TV3x_8_15_L ,	TV3x_8_16_L ,	TV3x_8_32_L },
-{	0,		TV3x_15_15_L,	TV3x_15_16_L,	TV3x_15_32_L},
-{	0,		TV3x_16_15_L,	TV3x_16_16_L,	TV3x_16_32_L},
-{	0,		TV3x_32_15_L,	TV3x_32_16_L,	TV3x_32_32_L},
-{	0,		TV3x_9_15_L ,	TV3x_9_16_L ,	TV3x_9_32_L }
+{	nullptr,	TV3x_8_15_L ,	TV3x_8_16_L ,	TV3x_8_32_L },
+{	nullptr,	TV3x_15_15_L,	TV3x_15_16_L,	TV3x_15_32_L},
+{	nullptr,	TV3x_16_15_L,	TV3x_16_16_L,	TV3x_16_32_L},
+{	nullptr,	TV3x_32_15_L,	TV3x_32_16_L,	TV3x_32_32_L},
+{	nullptr,	TV3x_9_15_L ,	TV3x_9_16_L ,	TV3x_9_32_L }
 },{
-{	0,		TV3x_8_15_R ,	TV3x_8_16_R ,	TV3x_8_32_R },
-{	0,		TV3x_15_15_R,	TV3x_15_16_R,	TV3x_15_32_R},
-{	0,		TV3x_16_15_R,	TV3x_16_16_R,	TV3x_16_32_R},
-{	0,		TV3x_32_15_R,	TV3x_32_16_R,	TV3x_32_32_R},
-{	0,		TV3x_9_15_R ,	TV3x_9_16_R ,	TV3x_9_32_R }
+{	nullptr,	TV3x_8_15_R ,	TV3x_8_16_R ,	TV3x_8_32_R },
+{	nullptr,	TV3x_15_15_R,	TV3x_15_16_R,	TV3x_15_32_R},
+{	nullptr,	TV3x_16_15_R,	TV3x_16_16_R,	TV3x_16_32_R},
+{	nullptr,	TV3x_32_15_R,	TV3x_32_16_R,	TV3x_32_32_R},
+{	nullptr,	TV3x_9_15_R ,	TV3x_9_16_R ,	TV3x_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleScan2x = {
 	"Scan2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,2,{
-{	0,		Scan2x_8_15_L ,	Scan2x_8_16_L ,	Scan2x_8_32_L },
-{	0,		Scan2x_15_15_L,	Scan2x_15_16_L,	Scan2x_15_32_L},
-{	0,		Scan2x_16_15_L,	Scan2x_16_16_L,	Scan2x_16_32_L},
-{	0,		Scan2x_32_15_L,	Scan2x_32_16_L,	Scan2x_32_32_L},
-{	0,		Scan2x_9_15_L ,	Scan2x_9_16_L ,	Scan2x_9_32_L }
+{	nullptr,	Scan2x_8_15_L ,	Scan2x_8_16_L ,	Scan2x_8_32_L },
+{	nullptr,	Scan2x_15_15_L,	Scan2x_15_16_L,	Scan2x_15_32_L},
+{	nullptr,	Scan2x_16_15_L,	Scan2x_16_16_L,	Scan2x_16_32_L},
+{	nullptr,	Scan2x_32_15_L,	Scan2x_32_16_L,	Scan2x_32_32_L},
+{	nullptr,	Scan2x_9_15_L ,	Scan2x_9_16_L ,	Scan2x_9_32_L }
 },{
-{	0,		Scan2x_8_15_R ,	Scan2x_8_16_R ,	Scan2x_8_32_R },
-{	0,		Scan2x_15_15_R,	Scan2x_15_16_R,	Scan2x_15_32_R},
-{	0,		Scan2x_16_15_R,	Scan2x_16_16_R,	Scan2x_16_32_R},
-{	0,		Scan2x_32_15_R,	Scan2x_32_16_R,	Scan2x_32_32_R},
-{	0,		Scan2x_9_15_R ,	Scan2x_9_16_R ,	Scan2x_9_32_R }
+{	nullptr,	Scan2x_8_15_R ,	Scan2x_8_16_R ,	Scan2x_8_32_R },
+{	nullptr,	Scan2x_15_15_R,	Scan2x_15_16_R,	Scan2x_15_32_R},
+{	nullptr,	Scan2x_16_15_R,	Scan2x_16_16_R,	Scan2x_16_32_R},
+{	nullptr,	Scan2x_32_15_R,	Scan2x_32_16_R,	Scan2x_32_32_R},
+{	nullptr,	Scan2x_9_15_R ,	Scan2x_9_16_R ,	Scan2x_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleScanDh = {
 	"Scan2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	1,2,{
-{	0,		ScanDh_8_15_L ,	ScanDh_8_16_L ,	ScanDh_8_32_L },
-{	0,		ScanDh_15_15_L,	ScanDh_15_16_L,	ScanDh_15_32_L},
-{	0,		ScanDh_16_15_L,	ScanDh_16_16_L,	ScanDh_16_32_L},
-{	0,		ScanDh_32_15_L,	ScanDh_32_16_L,	ScanDh_32_32_L},
-{	0,		ScanDh_9_15_L ,	ScanDh_9_16_L ,	ScanDh_9_32_L }
+{	nullptr,	ScanDh_8_15_L ,	ScanDh_8_16_L ,	ScanDh_8_32_L },
+{	nullptr,	ScanDh_15_15_L,	ScanDh_15_16_L,	ScanDh_15_32_L},
+{	nullptr,	ScanDh_16_15_L,	ScanDh_16_16_L,	ScanDh_16_32_L},
+{	nullptr,	ScanDh_32_15_L,	ScanDh_32_16_L,	ScanDh_32_32_L},
+{	nullptr,	ScanDh_9_15_L ,	ScanDh_9_16_L ,	ScanDh_9_32_L }
 },{
-{	0,		ScanDh_8_15_R ,	ScanDh_8_16_R ,	ScanDh_8_32_R },
-{	0,		ScanDh_15_15_R,	ScanDh_15_16_R,	ScanDh_15_32_R},
-{	0,		ScanDh_16_15_R,	ScanDh_16_16_R,	ScanDh_16_32_R},
-{	0,		ScanDh_32_15_R,	ScanDh_32_16_R,	ScanDh_32_32_R},
-{	0,		ScanDh_9_15_R ,	ScanDh_9_16_R ,	ScanDh_9_32_R }
+{	nullptr,	ScanDh_8_15_R ,	ScanDh_8_16_R ,	ScanDh_8_32_R },
+{	nullptr,	ScanDh_15_15_R,	ScanDh_15_16_R,	ScanDh_15_32_R},
+{	nullptr,	ScanDh_16_15_R,	ScanDh_16_16_R,	ScanDh_16_32_R},
+{	nullptr,	ScanDh_32_15_R,	ScanDh_32_16_R,	ScanDh_32_32_R},
+{	nullptr,	ScanDh_9_15_R ,	ScanDh_9_16_R ,	ScanDh_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleScan3x = {
 	"Scan3x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	3,3,{
-{	0,		Scan3x_8_15_L ,	Scan3x_8_16_L ,	Scan3x_8_32_L },
-{	0,		Scan3x_15_15_L,	Scan3x_15_16_L,	Scan3x_15_32_L},
-{	0,		Scan3x_16_15_L,	Scan3x_16_16_L,	Scan3x_16_32_L},
-{	0,		Scan3x_32_15_L,	Scan3x_32_16_L,	Scan3x_32_32_L},
-{	0,		Scan3x_9_15_L ,	Scan3x_9_16_L ,	Scan3x_9_32_L },
+{	nullptr,	Scan3x_8_15_L ,	Scan3x_8_16_L ,	Scan3x_8_32_L },
+{	nullptr,	Scan3x_15_15_L,	Scan3x_15_16_L,	Scan3x_15_32_L},
+{	nullptr,	Scan3x_16_15_L,	Scan3x_16_16_L,	Scan3x_16_32_L},
+{	nullptr,	Scan3x_32_15_L,	Scan3x_32_16_L,	Scan3x_32_32_L},
+{	nullptr,	Scan3x_9_15_L ,	Scan3x_9_16_L ,	Scan3x_9_32_L },
 },{
-{	0,		Scan3x_8_15_R ,	Scan3x_8_16_R ,	Scan3x_8_32_R },
-{	0,		Scan3x_15_15_R,	Scan3x_15_16_R,	Scan3x_15_32_R},
-{	0,		Scan3x_16_15_R,	Scan3x_16_16_R,	Scan3x_16_32_R},
-{	0,		Scan3x_32_15_R,	Scan3x_32_16_R,	Scan3x_32_32_R},
-{	0,		Scan3x_9_15_R ,	Scan3x_9_16_R ,	Scan3x_9_32_R }
+{	nullptr,	Scan3x_8_15_R ,	Scan3x_8_16_R ,	Scan3x_8_32_R },
+{	nullptr,	Scan3x_15_15_R,	Scan3x_15_16_R,	Scan3x_15_32_R},
+{	nullptr,	Scan3x_16_15_R,	Scan3x_16_16_R,	Scan3x_16_32_R},
+{	nullptr,	Scan3x_32_15_R,	Scan3x_32_16_R,	Scan3x_32_32_R},
+{	nullptr,	Scan3x_9_15_R ,	Scan3x_9_16_R ,	Scan3x_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleRGB2x = {
 	"RGB2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,2,{
-{	0,		RGB2x_8_15_L ,	RGB2x_8_16_L ,	RGB2x_8_32_L },
-{	0,		RGB2x_15_15_L,	RGB2x_15_16_L,	RGB2x_15_32_L},
-{	0,		RGB2x_16_15_L,	RGB2x_16_16_L,	RGB2x_16_32_L},
-{	0,		RGB2x_32_15_L,	RGB2x_32_16_L,	RGB2x_32_32_L},
-{	0,		RGB2x_9_15_L ,	RGB2x_9_16_L ,	RGB2x_9_32_L }
+{	nullptr,	RGB2x_8_15_L ,	RGB2x_8_16_L ,	RGB2x_8_32_L },
+{	nullptr,	RGB2x_15_15_L,	RGB2x_15_16_L,	RGB2x_15_32_L},
+{	nullptr,	RGB2x_16_15_L,	RGB2x_16_16_L,	RGB2x_16_32_L},
+{	nullptr,	RGB2x_32_15_L,	RGB2x_32_16_L,	RGB2x_32_32_L},
+{	nullptr,	RGB2x_9_15_L ,	RGB2x_9_16_L ,	RGB2x_9_32_L }
 },{
-{	0,		RGB2x_8_15_R ,	RGB2x_8_16_R ,	RGB2x_8_32_R },
-{	0,		RGB2x_15_15_R,	RGB2x_15_16_R,	RGB2x_15_32_R},
-{	0,		RGB2x_16_15_R,	RGB2x_16_16_R,	RGB2x_16_32_R},
-{	0,		RGB2x_32_15_R,	RGB2x_32_16_R,	RGB2x_32_32_R},
-{	0,		RGB2x_9_15_R ,	RGB2x_9_16_R ,	RGB2x_9_32_R }
+{	nullptr,	RGB2x_8_15_R ,	RGB2x_8_16_R ,	RGB2x_8_32_R },
+{	nullptr,	RGB2x_15_15_R,	RGB2x_15_16_R,	RGB2x_15_32_R},
+{	nullptr,	RGB2x_16_15_R,	RGB2x_16_16_R,	RGB2x_16_32_R},
+{	nullptr,	RGB2x_32_15_R,	RGB2x_32_16_R,	RGB2x_32_32_R},
+{	nullptr,	RGB2x_9_15_R ,	RGB2x_9_16_R ,	RGB2x_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleRGB3x = {
 	"RGB3x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	3,3,{
-{	0,		RGB3x_8_15_L ,	RGB3x_8_16_L ,	RGB3x_8_32_L },
-{	0,		RGB3x_15_15_L,	RGB3x_15_16_L,	RGB3x_15_32_L},
-{	0,		RGB3x_16_15_L,	RGB3x_16_16_L,	RGB3x_16_32_L},
-{	0,		RGB3x_32_15_L,	RGB3x_32_16_L,	RGB3x_32_32_L},
-{	0,		RGB3x_9_15_L ,	RGB3x_9_16_L ,	RGB3x_9_32_L }
+{	nullptr,	RGB3x_8_15_L ,	RGB3x_8_16_L ,	RGB3x_8_32_L },
+{	nullptr,	RGB3x_15_15_L,	RGB3x_15_16_L,	RGB3x_15_32_L},
+{	nullptr,	RGB3x_16_15_L,	RGB3x_16_16_L,	RGB3x_16_32_L},
+{	nullptr,	RGB3x_32_15_L,	RGB3x_32_16_L,	RGB3x_32_32_L},
+{	nullptr,	RGB3x_9_15_L ,	RGB3x_9_16_L ,	RGB3x_9_32_L }
 },{
-{	0,		RGB3x_8_15_R ,	RGB3x_8_16_R ,	RGB3x_8_32_R },
-{	0,		RGB3x_15_15_R,	RGB3x_15_16_R,	RGB3x_15_32_R},
-{	0,		RGB3x_16_15_R,	RGB3x_16_16_R,	RGB3x_16_32_R},
-{	0,		RGB3x_32_15_R,	RGB3x_32_16_R,	RGB3x_32_32_R},
-{	0,		RGB3x_9_15_R ,	RGB3x_9_16_R ,	RGB3x_9_32_R }
+{	nullptr,	RGB3x_8_15_R ,	RGB3x_8_16_R ,	RGB3x_8_32_R },
+{	nullptr,	RGB3x_15_15_R,	RGB3x_15_16_R,	RGB3x_15_32_R},
+{	nullptr,	RGB3x_16_15_R,	RGB3x_16_16_R,	RGB3x_16_32_R},
+{	nullptr,	RGB3x_32_15_R,	RGB3x_32_16_R,	RGB3x_32_32_R},
+{	nullptr,	RGB3x_9_15_R ,	RGB3x_9_16_R ,	RGB3x_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleGrayNormal = {
 	"Gray2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	1,1,{
-{	0,		GrayNormal_8_15_L ,	GrayNormal_8_16_L ,	GrayNormal_8_32_L },
-{	0,		GrayNormal_15_15_L,	GrayNormal_15_16_L,	GrayNormal_15_32_L},
-{	0,		GrayNormal_16_15_L,	GrayNormal_16_16_L,	GrayNormal_16_32_L},
-{	0,		GrayNormal_32_15_L,	GrayNormal_32_16_L,	GrayNormal_32_32_L},
-{	0,		GrayNormal_9_15_L ,	GrayNormal_9_16_L ,	GrayNormal_9_32_L }
+{	nullptr,	GrayNormal_8_15_L ,	GrayNormal_8_16_L ,	GrayNormal_8_32_L },
+{	nullptr,	GrayNormal_15_15_L,	GrayNormal_15_16_L,	GrayNormal_15_32_L},
+{	nullptr,	GrayNormal_16_15_L,	GrayNormal_16_16_L,	GrayNormal_16_32_L},
+{	nullptr,	GrayNormal_32_15_L,	GrayNormal_32_16_L,	GrayNormal_32_32_L},
+{	nullptr,	GrayNormal_9_15_L ,	GrayNormal_9_16_L ,	GrayNormal_9_32_L }
 },{
-{	0,		GrayNormal_8_15_R ,	GrayNormal_8_16_R ,	GrayNormal_8_32_R },
-{	0,		GrayNormal_15_15_R,	GrayNormal_15_16_R,	GrayNormal_15_32_R},
-{	0,		GrayNormal_16_15_R,	GrayNormal_16_16_R,	GrayNormal_16_32_R},
-{	0,		GrayNormal_32_15_R,	GrayNormal_32_16_R,	GrayNormal_32_32_R},
-{	0,		GrayNormal_9_15_R ,	GrayNormal_9_16_R ,	GrayNormal_9_32_R }
+{	nullptr,	GrayNormal_8_15_R ,	GrayNormal_8_16_R ,	GrayNormal_8_32_R },
+{	nullptr,	GrayNormal_15_15_R,	GrayNormal_15_16_R,	GrayNormal_15_32_R},
+{	nullptr,	GrayNormal_16_15_R,	GrayNormal_16_16_R,	GrayNormal_16_32_R},
+{	nullptr,	GrayNormal_32_15_R,	GrayNormal_32_16_R,	GrayNormal_32_32_R},
+{	nullptr,	GrayNormal_9_15_R ,	GrayNormal_9_16_R ,	GrayNormal_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleGrayDw = {
 	"Gray2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,1,{
-{	0,		GrayDw_8_15_L ,	GrayDw_8_16_L ,	GrayDw_8_32_L },
-{	0,		GrayDw_15_15_L,	GrayDw_15_16_L,	GrayDw_15_32_L},
-{	0,		GrayDw_16_15_L,	GrayDw_16_16_L,	GrayDw_16_32_L},
-{	0,		GrayDw_32_15_L,	GrayDw_32_16_L,	GrayDw_32_32_L},
-{	0,		GrayDw_9_15_L ,	GrayDw_9_16_L ,	GrayDw_9_32_L }
+{	nullptr,	GrayDw_8_15_L ,	GrayDw_8_16_L ,	GrayDw_8_32_L },
+{	nullptr,	GrayDw_15_15_L,	GrayDw_15_16_L,	GrayDw_15_32_L},
+{	nullptr,	GrayDw_16_15_L,	GrayDw_16_16_L,	GrayDw_16_32_L},
+{	nullptr,	GrayDw_32_15_L,	GrayDw_32_16_L,	GrayDw_32_32_L},
+{	nullptr,	GrayDw_9_15_L ,	GrayDw_9_16_L ,	GrayDw_9_32_L }
 },{
-{	0,		GrayDw_8_15_R ,	GrayDw_8_16_R ,	GrayDw_8_32_R },
-{	0,		GrayDw_15_15_R,	GrayDw_15_16_R,	GrayDw_15_32_R},
-{	0,		GrayDw_16_15_R,	GrayDw_16_16_R,	GrayDw_16_32_R},
-{	0,		GrayDw_32_15_R,	GrayDw_32_16_R,	GrayDw_32_32_R},
-{	0,		GrayDw_9_15_R ,	GrayDw_9_16_R ,	GrayDw_9_32_R }
+{	nullptr,	GrayDw_8_15_R ,	GrayDw_8_16_R ,	GrayDw_8_32_R },
+{	nullptr,	GrayDw_15_15_R,	GrayDw_15_16_R,	GrayDw_15_32_R},
+{	nullptr,	GrayDw_16_15_R,	GrayDw_16_16_R,	GrayDw_16_32_R},
+{	nullptr,	GrayDw_32_15_R,	GrayDw_32_16_R,	GrayDw_32_32_R},
+{	nullptr,	GrayDw_9_15_R ,	GrayDw_9_16_R ,	GrayDw_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleGrayDh = {
 	"Gray2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	1,2,{
-{	0,		GrayDh_8_15_L ,	GrayDh_8_16_L ,	GrayDh_8_32_L },
-{	0,		GrayDh_15_15_L,	GrayDh_15_16_L,	GrayDh_15_32_L},
-{	0,		GrayDh_16_15_L,	GrayDh_16_16_L,	GrayDh_16_32_L},
-{	0,		GrayDh_32_15_L,	GrayDh_32_16_L,	GrayDh_32_32_L},
-{	0,		GrayDh_9_15_L ,	GrayDh_9_16_L ,	GrayDh_9_32_L }
+{	nullptr,	GrayDh_8_15_L ,	GrayDh_8_16_L ,	GrayDh_8_32_L },
+{	nullptr,	GrayDh_15_15_L,	GrayDh_15_16_L,	GrayDh_15_32_L},
+{	nullptr,	GrayDh_16_15_L,	GrayDh_16_16_L,	GrayDh_16_32_L},
+{	nullptr,	GrayDh_32_15_L,	GrayDh_32_16_L,	GrayDh_32_32_L},
+{	nullptr,	GrayDh_9_15_L ,	GrayDh_9_16_L ,	GrayDh_9_32_L }
 },{
-{	0,		GrayDh_8_15_R ,	GrayDh_8_16_R ,	GrayDh_8_32_R },
-{	0,		GrayDh_15_15_R,	GrayDh_15_16_R,	GrayDh_15_32_R},
-{	0,		GrayDh_16_15_R,	GrayDh_16_16_R,	GrayDh_16_32_R},
-{	0,		GrayDh_32_15_R,	GrayDh_32_16_R,	GrayDh_32_32_R},
-{	0,		GrayDh_9_15_R ,	GrayDh_9_16_R ,	GrayDh_9_32_R }
+{	nullptr,	GrayDh_8_15_R ,	GrayDh_8_16_R ,	GrayDh_8_32_R },
+{	nullptr,	GrayDh_15_15_R,	GrayDh_15_16_R,	GrayDh_15_32_R},
+{	nullptr,	GrayDh_16_15_R,	GrayDh_16_16_R,	GrayDh_16_32_R},
+{	nullptr,	GrayDh_32_15_R,	GrayDh_32_16_R,	GrayDh_32_32_R},
+{	nullptr,	GrayDh_9_15_R ,	GrayDh_9_16_R ,	GrayDh_9_32_R }
 }};
 
 ScalerSimpleBlock_t ScaleGray2x = {
 	"Gray2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,2,{
-{	0,		Gray2x_8_15_L ,	Gray2x_8_16_L ,	Gray2x_8_32_L },
-{	0,		Gray2x_15_15_L,	Gray2x_15_16_L,	Gray2x_15_32_L},
-{	0,		Gray2x_16_15_L,	Gray2x_16_16_L,	Gray2x_16_32_L},
-{	0,		Gray2x_32_15_L,	Gray2x_32_16_L,	Gray2x_32_32_L},
-{	0,		Gray2x_9_15_L ,	Gray2x_9_16_L ,	Gray2x_9_32_L }
+{	nullptr,	Gray2x_8_15_L ,	Gray2x_8_16_L ,	Gray2x_8_32_L },
+{	nullptr,	Gray2x_15_15_L,	Gray2x_15_16_L,	Gray2x_15_32_L},
+{	nullptr,	Gray2x_16_15_L,	Gray2x_16_16_L,	Gray2x_16_32_L},
+{	nullptr,	Gray2x_32_15_L,	Gray2x_32_16_L,	Gray2x_32_32_L},
+{	nullptr,	Gray2x_9_15_L ,	Gray2x_9_16_L ,	Gray2x_9_32_L }
 },{
-{	0,		Gray2x_8_15_R ,	Gray2x_8_16_R ,	Gray2x_8_32_R },
-{	0,		Gray2x_15_15_R,	Gray2x_15_16_R,	Gray2x_15_32_R},
-{	0,		Gray2x_16_15_R,	Gray2x_16_16_R,	Gray2x_16_32_R},
-{	0,		Gray2x_32_15_R,	Gray2x_32_16_R,	Gray2x_32_32_R},
-{	0,		Gray2x_9_15_R ,	Gray2x_9_16_R ,	Gray2x_9_32_R }
+{	nullptr,	Gray2x_8_15_R ,	Gray2x_8_16_R ,	Gray2x_8_32_R },
+{	nullptr,	Gray2x_15_15_R,	Gray2x_15_16_R,	Gray2x_15_32_R},
+{	nullptr,	Gray2x_16_15_R,	Gray2x_16_16_R,	Gray2x_16_32_R},
+{	nullptr,	Gray2x_32_15_R,	Gray2x_32_16_R,	Gray2x_32_32_R},
+{	nullptr,	Gray2x_9_15_R ,	Gray2x_9_16_R ,	Gray2x_9_32_R }
 }};
 #endif
 
@@ -587,56 +587,56 @@ ScalerComplexBlock_t ScaleHQ2x ={
 	"HQ2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,2,
-{	0,HQ2x_16_L,HQ2x_16_L,HQ2x_32_L},
-{	0,HQ2x_16_R,HQ2x_16_R,HQ2x_32_R}
+{	nullptr,HQ2x_16_L,HQ2x_16_L,HQ2x_32_L},
+{	nullptr,HQ2x_16_R,HQ2x_16_R,HQ2x_32_R}
 };
 
 ScalerComplexBlock_t ScaleHQ3x ={
 	"HQ3x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	3,3,
-{	0,HQ3x_16_L,HQ3x_16_L,HQ3x_32_L},
-{	0,HQ3x_16_R,HQ3x_16_R,HQ3x_32_R}
+{	nullptr,HQ3x_16_L,HQ3x_16_L,HQ3x_32_L},
+{	nullptr,HQ3x_16_R,HQ3x_16_R,HQ3x_32_R}
 };
 
 ScalerComplexBlock_t ScaleSuper2xSaI ={
 	"Super2xSaI",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,2,
-{	0,Super2xSaI_16_L,Super2xSaI_16_L,Super2xSaI_32_L},
-{	0,Super2xSaI_16_R,Super2xSaI_16_R,Super2xSaI_32_R}
+{	nullptr,Super2xSaI_16_L,Super2xSaI_16_L,Super2xSaI_32_L},
+{	nullptr,Super2xSaI_16_R,Super2xSaI_16_R,Super2xSaI_32_R}
 };
 
 ScalerComplexBlock_t Scale2xSaI ={
 	"2xSaI",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,2,
-{	0,_2xSaI_16_L,_2xSaI_16_L,_2xSaI_32_L},
-{	0,_2xSaI_16_R,_2xSaI_16_R,_2xSaI_32_R}
+{	nullptr,_2xSaI_16_L,_2xSaI_16_L,_2xSaI_32_L},
+{	nullptr,_2xSaI_16_R,_2xSaI_16_R,_2xSaI_32_R}
 };
 
 ScalerComplexBlock_t ScaleSuperEagle ={
 	"SuperEagle",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,2,
-{	0,SuperEagle_16_L,SuperEagle_16_L,SuperEagle_32_L},
-{	0,SuperEagle_16_R,SuperEagle_16_R,SuperEagle_32_R}
+{	nullptr,SuperEagle_16_L,SuperEagle_16_L,SuperEagle_32_L},
+{	nullptr,SuperEagle_16_R,SuperEagle_16_R,SuperEagle_32_R}
 };
 
 ScalerComplexBlock_t ScaleAdvInterp2x = {
 	"AdvInterp2x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	2,2,
-{	0,AdvInterp2x_15_L,AdvInterp2x_16_L,AdvInterp2x_32_L},
-{	0,AdvInterp2x_15_R,AdvInterp2x_16_R,AdvInterp2x_32_R}
+{	nullptr,AdvInterp2x_15_L,AdvInterp2x_16_L,AdvInterp2x_32_L},
+{	nullptr,AdvInterp2x_15_R,AdvInterp2x_16_R,AdvInterp2x_32_R}
 };
 
 ScalerComplexBlock_t ScaleAdvInterp3x = {
 	"AdvInterp3x",
 	GFX_CAN_15|GFX_CAN_16|GFX_CAN_32|GFX_RGBONLY,
 	3,3,
-{	0,AdvInterp3x_15_L,AdvInterp3x_16_L,AdvInterp3x_32_L},
-{	0,AdvInterp3x_15_R,AdvInterp3x_16_R,AdvInterp3x_32_R}
+{	nullptr,AdvInterp3x_15_L,AdvInterp3x_16_L,AdvInterp3x_32_L},
+{	nullptr,AdvInterp3x_15_R,AdvInterp3x_16_R,AdvInterp3x_32_R}
 };
 
 #endif
