@@ -342,6 +342,7 @@ void vsync_poll_debug_notify() {
         vga_3da_polled = true;
 }
 
+uint32_t HercBlend_2_Table[16];
 uint32_t CGA_2_Table[16];
 uint32_t CGA_4_Table[256];
 uint32_t CGA_4_HiRes_Table[256];
@@ -601,7 +602,7 @@ static void resetSize(Bitu /*val*/) {
 
 class VFRCRATE : public Program {
 public:
-    void Run(void) {
+    void Run(void) override {
         if (cmd->FindExist("/?", false)) {
 			WriteOut("Locks or unlocks the video refresh rate.\n\n");
 			WriteOut("VFRCRATE [SET [OFF|PAL|NTSC|rate]\n");
@@ -643,7 +644,7 @@ class CGASNOW : public Program {
 public:
     /*! \brief      Program entry point, when the command is run
      */
-    void Run(void) {
+    void Run(void) override {
         if (cmd->FindExist("/?", false)) {
 			WriteOut("Turns CGA snow emulation on or off.\n\n");
 			WriteOut("CGASNOW [ON|OFF]\n");
@@ -1216,6 +1217,22 @@ void VGA_Reset(Section*) {
         /* Generate tables */
         VGA_SetCGA2Table(0,1);
         VGA_SetCGA4Table(0,1,2,3);
+
+        if (machine == MCH_HERC || machine == MCH_MDA) {
+            /* alternate table for blend mode, expect mapping 0=black 1-7=gray 8=black 9-f=white
+             * for use with blend code that reads this table and sums the output with a delayed version of the same */
+            const uint8_t total[2] = {0x0,0x05}; /* blending will yield {0,5,10} which is sufficient to recreate the effect */
+            for (Bitu i=0;i<16u;i++) {
+                HercBlend_2_Table[i]=
+#ifdef WORDS_BIGENDIAN
+                    ((Bitu)total[(i >> 0u) & 1u] << 0u  ) | ((Bitu)total[(i >> 1u) & 1u] << 8u  ) |
+                    ((Bitu)total[(i >> 2u) & 1u] << 16u ) | ((Bitu)total[(i >> 3u) & 1u] << 24u );
+#else 
+                    ((Bitu)total[(i >> 3u) & 1u] << 0u  ) | ((Bitu)total[(i >> 2u) & 1u] << 8u  ) |
+                    ((Bitu)total[(i >> 1u) & 1u] << 16u ) | ((Bitu)total[(i >> 0u) & 1u] << 24u );
+#endif
+            }
+        }
     }
 
     Section_prop * section2=static_cast<Section_prop *>(control->GetSection("vsync"));
@@ -2116,7 +2133,7 @@ public:
 	{}
 
 private:
-	virtual void getBytes(std::ostream& stream)
+	void getBytes(std::ostream& stream) override
 	{
 		uint32_t tandy_drawbase_idx, tandy_membase_idx;
 
@@ -2234,7 +2251,7 @@ private:
 		POD_Save_VGA_XGA(stream);
 	}
 
-	virtual void setBytes(std::istream& stream)
+	void setBytes(std::istream& stream) override
 	{
 		uint32_t tandy_drawbase_idx, tandy_membase_idx;
 
